@@ -2,7 +2,6 @@
 
 from __future__ import annotations
 
-import copy
 import glob
 import os
 import posixpath
@@ -109,6 +108,7 @@ class PythonHandler(BaseHandler):
         "annotations_path": "brief",
         "preload_modules": None,
         "allow_inspection": True,
+        "unwrap_annotated": False,
     }
     """
     Attributes: General options:
@@ -180,6 +180,7 @@ class PythonHandler(BaseHandler):
         signature_crossrefs (bool): Whether to render cross-references for type annotations in signatures. Default: `False`.
         separate_signature (bool): Whether to put the whole signature in a code block below the heading.
             If Black is installed, the signature is also formatted using it. Default: `False`.
+        unwrap_annotated (bool): Whether to unwrap `Annotated` types to show only the type without the annotations. Default: `False`.
     """
 
     def __init__(
@@ -258,9 +259,7 @@ class PythonHandler(BaseHandler):
         if config.get("fallback", False) and unknown_module:
             raise CollectionError("Not loading additional modules during fallback")
 
-        # See: https://github.com/python/typeshed/issues/8430
-        mutable_config = dict(copy.deepcopy(config))
-        final_config = ChainMap(mutable_config, self.default_config)
+        final_config = ChainMap(config, self.default_config)  # type: ignore[arg-type]
         parser_name = final_config["docstring_style"]
         parser_options = final_config["docstring_options"]
         parser = parser_name and Parser(parser_name)
@@ -306,9 +305,7 @@ class PythonHandler(BaseHandler):
         return doc_object
 
     def render(self, data: CollectorItem, config: Mapping[str, Any]) -> str:  # noqa: D102 (ignore missing docstring)
-        # See https://github.com/python/typeshed/issues/8430
-        mutabled_config = dict(copy.deepcopy(config))
-        final_config = ChainMap(mutabled_config, self.default_config)
+        final_config = ChainMap(config, self.default_config)  # type: ignore[arg-type]
 
         template_name = rendering.do_get_template(data)
         template = self.env.get_template(template_name)
